@@ -1,7 +1,7 @@
 package App::Mobirc::Plugin::MessageBodyFilter::Clickable;
 # vim:expandtab:
 use strict;
-use App::Mobirc::Plugin;
+use MooseX::Plaggerize::Plugin;
 use URI::Find;
 use URI::Escape;
 use HTML::Entities;
@@ -38,7 +38,6 @@ has au_pcsv => (
 has pocket_hatena => (
     is  => 'ro',
     isa => 'Bool',
-    default => 1,
 );
 
 has google_gwt => (
